@@ -53,11 +53,11 @@ fn main() {
 
         let mut rate: f64 = 0.0;
         for state in qsim.state().iter() {
-            let bin: Vec<char> = state.to_binary_chars();
-            let (m0, _) = bin.split_at(r0.len());
+            let m0: Vec<char> = state.to_binary_chars(&r0);
 
-            let (_s, _r, ok) = number::find_order(a, n, m0);
+            let (_s, _r, ok) = number::find_order(a, n, &m0);
             if !ok || number::is_odd(_r) {
+                println!("{} s/r={:>2}/{:>2};", state, _s, _r);
                 continue;
             }
 
@@ -65,10 +65,11 @@ fn main() {
             let p1: u32 = number::gcd(a.pow(_r / 2) + 1, n);
 
             if number::is_trivial(n, &[p0, p1]) {
+                println!("{} s/r={:>2}/{:>2}; p={}, q={}", state, _s, _r, p0, p1);
                 continue;
             }
 
-            println!("p={}, q={}; {} s/r={:>2}/{:>2}", p0, p1, state, _s, _r);
+            println!("{} s/r={:>2}/{:>2}; p={}, q={}", state, _s, _r, p0, p1);
             rate += state.prob;
         }
 
